@@ -7,6 +7,7 @@
 import logging
 import os
 import sys
+import traceback
 
 from mobio.libs.Singleton import Singleton
 from mobio.sdks.base.common import CONSTANTS
@@ -56,14 +57,16 @@ class MobioLogging:
     def debug(self, content, log_key=None):
         if isinstance(content, dict) and LoggingConfig.K8S:
             content["log_key"] = log_key
-        self.logger.warning(content)
+        traceback.print_last()
+        self.logger.debug(content)
 
     def error(self, content, log_key=None):
         if isinstance(content, dict) and LoggingConfig.K8S:
             content["log_key"] = log_key
-        self.logger.warning(content)
+        traceback.print_exc()
+        self.logger.error(content)
 
     def info(self, content, log_key=None):
         if isinstance(content, dict) and LoggingConfig.K8S:
             content["log_key"] = log_key
-        self.logger.warning(content)
+        self.logger.info(content)
